Backoff

Enum Backoff 

pub enum Backoff {
    Linear {
        current: usize,
        limit: usize,
    },
    Exponential {
        current: usize,
        limit: usize,
    },
}
A stateful backoff strategy used to reduce CPU contention in busy-wait loops.

This enum encapsulates both the configuration and the current state of the backoff. It uses “Full Jitter” to prevent “thundering herd” problems by picking a random number of spins between 0 and the current limit.

Variants



Linear

Linear growth: increases the maximum spin count by 1 each step until it hits the limit.

Fields

current: usize

The current maximum number of spins for the next jitter calculation.

limit: usize

The maximum allowed value for current.



Exponential

Exponential growth: doubles the maximum spin count each step until it hits the limit.

Fields

current: usize

The current maximum number of spins for the next jitter calculation.

limit: usize

The maximum allowed value for current.

Implementations

Source

impl Backoff

pub fn linear(limit: usize) -> Self

Creates a new linear backoff starting with a maximum spin of 1.

At each call to [backoff], the internal limit will increase by 1 until limit is reached.

pub fn exponential(limit: usize) -> Self

Creates a new exponential backoff starting with a maximum spin of 1.

At each call to [backoff], the internal limit will double (multiplicative growth) until limit is reached.

pub fn backoff(&mut self)

Performs the backoff by spinning the CPU.

This method:

  1. Generates a random number jitter from 0 to ${limit}.
  2. Executes std::hint::spin_loop() jitter times.
  3. Increments the internal limit according to the chosen strategy.