pub struct Entry<K, V>{ /* private fields */ }Expand description
Implementations
Sourceimpl<K, V> Entry<K, V>
impl<K, V> Entry<K, V>
pub fn with_ttl(key: K, value: V, ttl: Duration) -> Self
pub fn with_custom_expiration( key: K, value: V, is_expire: impl Fn() -> bool + 'static + Send + Sync, ) -> Self
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Checks if the entry has passed its expiration deadline.
Returns true if expired_at is a time in the past relative to Instant::now.
If no expiration was set, this always returns false.