Structs
- Thread
Context ThreadContextmaintains the long-lived, persistent contention state of a specific thread as it interacts with a specific cache instance.
ThreadContext maintains the long-lived, persistent contention state of a
specific thread as it interacts with a specific cache instance.