Cache

Struct Cache 

pub struct Cache<E, K, V>
where E: CacheEngine<K, V>, K: Eq + Hash,
{ /* private fields */ }

Implementations

Source

impl<E, K, V> Cache<E, K, V>
where E: CacheEngine<K, V>, K: Eq + Hash,

pub fn new(engine: E, backoff_config: BackoffConfig) -> Self

pub fn get<Q>(&self, key: &Q) -> Option<Ref<K, V>>
where Key<K>: Borrow<Q>, Q: Eq + Hash + ?Sized,

Retrieves a value from the cache.

If the key exists, the admission policy is notified of the access.

Returns a Ref handle that provides controlled access to the entry.

The entry is pinned in memory for the duration of the handle’s life using epoch-based memory reclamation.

pub fn insert(&self, key: K, value: V)

Inserts a key-value pair into the cache.

Arguments
  • key - The key to associate with the value.
  • value - The value to be cached.
pub fn insert_with_ttl(&self, key: K, value: V, ttl: Duration)

Inserts a key-value pair into the cache with a specific Time-to-Live (TTL).

The entry will be automatically considered expired after the specified ttl duration has elapsed.

Arguments
  • key - The key to associate with the value.
  • value - The value to be cached.
  • ttl - The duration for which the entry should remain valid.
pub fn remove<Q>(&self, key: &Q) -> bool
where Key<K>: Borrow<Q>, Q: Eq + Hash + ?Sized,

Removes an entry from the cache.

Returns true if the entry was found and successfully removed.

pub fn metrics(&self) -> MetricsSnapshot