pub struct Entry<K, V>{ /* private fields */ }Expand description
Implementations
Sourceimpl<K, V> Entry<K, V>
impl<K, V> Entry<K, V>
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Checks if the entry has passed its expiration deadline.
Returns true if expired_at is a time in the past relative to Instant::now.
If no expiration was set, this always returns false.
Examples
use std::time::{Duration, Instant};
use omega_cache::core::entry::Entry;
// Entry that expired 1 second ago
let past = Instant::now() - Duration::from_secs(1);
let entry = Entry::new("key", "value", Some(past));
assert!(entry.is_expired());Trait Implementations