pub struct Index(/* private fields */);Expand description
A 64-bit versioned pointer.
Combines a 16-bit version ID with a 48-bit slot index. This ensures that an index pointing to an old version of a slot cannot be used after the slot has been advanced.
Implementations